#
# spec file for package ghc-aeson-pretty
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name aeson-pretty
Name:           ghc-%{pkg_name}
Version:        0.8.9
Release:        150500.1.1
Summary:        JSON pretty-printing library and command-line tool
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/2.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
ExcludeArch:    %{ix86}

%description
A JSON pretty-printing library compatible with aeson as well as a command-line
tool to improve readabilty of streams of JSON data.

The /library/ provides the function "encodePretty". It is a drop-in replacement
for aeson's "encode" function, producing JSON-ByteStrings for human readers.

The /command-line tool/ reads JSON from stdin and writes prettified JSON to
stdout. It also offers a complementary "compact"-mode, essentially the opposite
of pretty-printing. If you specify '-flib-only' like this

> cabal install -flib-only aeson-pretty

the command-line tool will NOT be installed.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%define cabal_configure_options -flib-only
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown

%changelog
* Fri Jun 17 2022 psimons@suse.com
- Update aeson-pretty to version 0.8.9 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov 15 2021 psimons@suse.com
- Update aeson-pretty to version 0.8.9 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update aeson-pretty to version 0.8.9.
  Upstream added a new change log file in this release. With no
  previous version to compare against, the automatic updater cannot
  reliable determine the relevante entries for this release.
* Tue Oct 12 2021 psimons@suse.com
- Update aeson-pretty to version 0.8.8 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 mimi.vx@gmail.com
- disable %%{ix86} build
* Tue Aug 18 2020 psimons@suse.com
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 psimons@suse.com
- Re-generate file with latest version of spec-cleaner.
* Thu May  7 2020 psimons@suse.com
- Enable 'lib-only' flag to reduce the required dependencies.
* Fri Nov  8 2019 psimons@suse.com
- Drop obsolete group attributes.
* Sat Sep 28 2019 psimons@suse.com
- Update aeson-pretty to version 0.8.8.
  Upstream does not provide a change log file.
* Sat Oct 20 2018 psimons@suse.com
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update aeson-pretty to version 0.8.7.
  Upstream does not provide a changelog.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jun 19 2017 psimons@suse.com
- Update to version 0.8.5.
* Wed May 31 2017 psimons@suse.com
- Update to version 0.8.4.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.8.2 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.7.2 revision 0 with cabal2obs.
* Thu Aug  6 2015 mimi.vx@gmail.com
- moved aeson-pretty binary from devel package to normal
* Tue Jun  9 2015 jmatejka@suse.cz
- Initial package
